@@ -1,6 +1,6 @@
 package TPath::Forester;
 {
-  $TPath::Forester::VERSION = '0.006';
+  $TPath::Forester::VERSION = '0.007';
 }
 
 # ABSTRACT: a generator of TPath expressions for a particular class of nodes
@@ -372,7 +372,7 @@ TPath::Forester - a generator of TPath expressions for a particular class of nod
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -545,6 +545,27 @@ Expects a node and possibly an options hash. Returns a node of the type understo
 If your forester must coerce things into a tree of the right type, override this method, which otherwise
 just passes through its second argument.
 
+Note, if you do need to override the default wrap, you'll have to jump through a few Moose hoops. The
+basic pattern is
+
+  ...
+  use Moose;
+  ...
+  with 'TPath::Forester' => { -excludes => 'wrap' };
+  ...
+
+  {
+      no warnings 'redefine';
+      sub wrap {
+          my ($self, $node, %opts) = @_;
+          return $node if blessed $node and $node->isa('MyNode');
+          # coerce
+          ...
+      }
+  }
+
+See L<TPath::Forester::Ref> for an example.
+
 =head1 ROLES
 
 L<TPath::Attributes::Standard>, L<TPath::TypeCheck>
